/*
 * d_regs.c - dump some important registers
 *   by uratan! 2014.10.14
 */
#include "common.h"
#include <chip.h>

/*
 * choice target registers
 */
#define DUMP_SCB       0
#define DUMP_NVIC      0
#define  DUMP_SYSTICK   1
#define DUMP_SYSCTRL   0
#define DUMP_SYSCTRL_FULL   0
#define DUMP_FMC       0
#define DUMP_IOCON     0
#define DUMP_SWM       0
#define  DUMP_GPIO      0
#define  DUMP_UART0     0
#define  DUMP_UART1     0

/*
 *
 */
#define rdump(name,desc,regv)   rprintf(" %08x =" name /*desc*/ "\r\n", regv)

/*
 *
 */
void dump_some_regs(void)
{
#if DUMP_SCB
	rprintf("SCB\r\n");
	rdump("CPUID", "        CPUID Base",									SCB->CPUID);
	rdump("ICSR", "         Interrupt Control and State Reg",				SCB->ICSR);
	rdump("VTOR", "         Vector Table Offset Reg",						SCB->VTOR);
	rdump("AIRCR", "        Application Interrupt and Reset Control Reg",	SCB->AIRCR);
	rdump("SCR", "          System Control Reg (SLEEPDEEP)",				SCB->SCR);
	rdump("CCR", "          Configuration Control Reg",						SCB->CCR);
	rdump("SHP[0]", "       System Handlers Priority 2 (SVCall)",			SCB->SHP[0]);
	rdump("SHP[1]", "       System Handlers Priority 3 (SysTick, PendSV)",	SCB->SHP[1]);
	rdump("SHCSR", "        System Handler Control and State Reg",			SCB->SHCSR);
#endif /* DUMP_SCB */
#if DUMP_NVIC
	rprintf("NVIC\r\n");
	rdump("ISER[0]", "      Interrupt Set Enable Reg",			NVIC->ISER[0]);
	rdump("ICER[0]", "      Interrupt Clear Enable Reg",		NVIC->ICER[0]);
	rdump("ISPR[0]", "      Interrupt Set Pending Reg",			NVIC->ISPR[0]);
	rdump("ICPR[0]", "      Interrupt Clear Pending Reg",		NVIC->ICPR[0]);
	rdump("IP[0]", "        Interrupt Priority (#0-#3)",		NVIC->IP[0]);
	rdump("IP[1]", "        Interrupt Priority (#4-#7)",		NVIC->IP[1]);
	rdump("IP[2]", "        Interrupt Priority (#8-#11)",		NVIC->IP[2]);
	rdump("IP[3]", "        Interrupt Priority (#12-#15)",		NVIC->IP[3]);
	rdump("IP[4]", "        Interrupt Priority (RSRV)",			NVIC->IP[4]);
	rdump("IP[5]", "        Interrupt Priority (RSRV)",			NVIC->IP[5]);
	rdump("IP[6]", "        Interrupt Priority (#24-#27)",		NVIC->IP[6]);
	rdump("IP[7]", "        Interrupt Priority (#28-#31)",		NVIC->IP[7]);
#endif /* DUMP_NVIC */
#if DUMP_SYSTICK
	rprintf("SysTick\r\n");
	rdump("CTRL", "         SysTick Control and Status",	SysTick->CTRL);
	rdump("LOAD", "         SysTick Reload Value",			SysTick->LOAD);
	rdump("VAL", "          SysTick Current Value",			SysTick->VAL);
	rdump("CALIB", "        SysTick Calibration",			SysTick->CALIB);
#endif /* DUMP_SYSTICK */
#if DUMP_SYSCTRL
	rprintf("LPC_SYSCTL\r\n");
	rdump("SYSMEMREMAP", "  System memory remap",					LPC_SYSCTL->SYSMEMREMAP);
	rdump("PRESETCTRL", "   Peripheral reset control",				LPC_SYSCTL->PRESETCTRL);
	rdump("SYSPLLCTRL", "   System PLL control",					LPC_SYSCTL->SYSPLLCTRL);
	rdump("SYSPLLSTAT", "   System PLL status",						LPC_SYSCTL->SYSPLLSTAT);
	rdump("SYSOSCCTRL", "   System oscillator control",				LPC_SYSCTL->SYSOSCCTRL);
	rdump("WDTOSCCTRL", "   Watchdog oscillator control",			LPC_SYSCTL->WDTOSCCTRL);
	rdump("SYSRSTSTAT", "   System reset status Reg",				LPC_SYSCTL->SYSRSTSTAT);
	rdump("SYSPLLCLKSEL", " System PLL clock source select",		LPC_SYSCTL->SYSPLLCLKSEL);
	rdump("SYSPLLCLKUEN", " System PLL clock source update enable",	LPC_SYSCTL->SYSPLLCLKUEN);
	rdump("MAINCLKSEL", "   Main clock source select",				LPC_SYSCTL->MAINCLKSEL);
	rdump("MAINCLKUEN", "   Main clock source update enable",		LPC_SYSCTL->MAINCLKUEN);
	rdump("SYSAHBCLKDIV", "  System AHB clock divider",			LPC_SYSCTL->SYSAHBCLKDIV);
	rdump("SYSAHBCLKCTRL", " System AHB clock control",			LPC_SYSCTL->SYSAHBCLKCTRL);
	rdump("UARTCLKDIV", "   UART clock divider",					LPC_SYSCTL->UARTCLKDIV);
	rdump("CLKOUTSEL", "    CLKOUT clock source select",			LPC_SYSCTL->CLKOUTSEL);
	rdump("CLKOUTUEN", "    CLKOUT clock source update enable",		LPC_SYSCTL->CLKOUTUEN);
	rdump("CLKOUTDIV", "    CLKOUT clock divider",					LPC_SYSCTL->CLKOUTDIV);
	rdump("UARTFRGDIV", "   UART fractional divider SUB",			LPC_SYSCTL->UARTFRGDIV);
	rdump("UARTFRGMULT", "  UART fractional divider ADD",			LPC_SYSCTL->UARTFRGMULT);
#if DUMP_SYSCTRL_FULL
	rdump("EXTTRACECMD", "  External trace buffer command",			LPC_SYSCTL->EXTTRACECMD);
	rdump("PIOPORCAP0", "   POR captured PIO status 0",				LPC_SYSCTL->PIOPORCAP0);
	rdump("IOCONCLKDIV[0]", " IOCON glitch filter divider 6",		LPC_SYSCTL->IOCONCLKDIV[0]);
	rdump("IOCONCLKDIV[1]", " IOCON glitch filter divider 5",		LPC_SYSCTL->IOCONCLKDIV[1]);
	rdump("IOCONCLKDIV[2]", " IOCON glitch filter divider 4",		LPC_SYSCTL->IOCONCLKDIV[2]);
	rdump("IOCONCLKDIV[3]", " IOCON glitch filter divider 3",		LPC_SYSCTL->IOCONCLKDIV[3]);
	rdump("IOCONCLKDIV[4]", " IOCON glitch filter divider 2",		LPC_SYSCTL->IOCONCLKDIV[4]);
	rdump("IOCONCLKDIV[5]", " IOCON glitch filter divider 1",		LPC_SYSCTL->IOCONCLKDIV[5]);
	rdump("IOCONCLKDIV[6]", " IOCON glitch filter divider 0",		LPC_SYSCTL->IOCONCLKDIV[6]);
	rdump("BODCTRL", "      BOD control",							LPC_SYSCTL->BODCTRL);
	rdump("SYSTCKCAL", "    System tick counter calibration",		LPC_SYSCTL->SYSTCKCAL);
	rdump("IRQLATENCY", "   IRQ delay",								LPC_SYSCTL->IRQLATENCY);
	rdump("NMISRC", "       NMI Source Control",					LPC_SYSCTL->NMISRC);
	rdump("PINTSEL[0]", "   GPIO Pin Interrupt Select 0",			LPC_SYSCTL->PINTSEL[0]);
	rdump("PINTSEL[1]", "   GPIO Pin Interrupt Select 1",			LPC_SYSCTL->PINTSEL[1]);
	rdump("PINTSEL[2]", "   GPIO Pin Interrupt Select 2",			LPC_SYSCTL->PINTSEL[2]);
	rdump("PINTSEL[3]", "   GPIO Pin Interrupt Select 3",			LPC_SYSCTL->PINTSEL[3]);
	rdump("PINTSEL[4]", "   GPIO Pin Interrupt Select 4",			LPC_SYSCTL->PINTSEL[4]);
	rdump("PINTSEL[5]", "   GPIO Pin Interrupt Select 5",			LPC_SYSCTL->PINTSEL[5]);
	rdump("PINTSEL[6]", "   GPIO Pin Interrupt Select 6",			LPC_SYSCTL->PINTSEL[6]);
	rdump("PINTSEL[7]", "   GPIO Pin Interrupt Select 7",			LPC_SYSCTL->PINTSEL[7]);
	rdump("STARTERP0", "    Start logic signal enable Reg 0",		LPC_SYSCTL->STARTERP0);
	rdump("STARTERP1", "    Start logic signal enable Reg 1",		LPC_SYSCTL->STARTERP1);
	rdump("PDSLEEPCFG", "   Power-down states in Deep-sleep mode",	LPC_SYSCTL->PDSLEEPCFG);
	rdump("PDAWAKECFG", "   Power-down states after wake-up",		LPC_SYSCTL->PDAWAKECFG);
#endif /* DUMP_SYSCTRL_FULL */
	rdump("PDRUNCFG", "     Power-down configuration",				LPC_SYSCTL->PDRUNCFG);
	rdump("DEVICEID", "     Device ID",								LPC_SYSCTL->DEVICEID);
#endif /* DUMP_SYSCTRL */
#if DUMP_FMC
	rprintf("LPC_FMC\r\n");
	rdump("FLASHCFG", "     Flash Configuration",			LPC_FMC->FLASHCFG);
	rdump("FMSSTART", "     Signature start address",		LPC_FMC->FMSSTART);
	rdump("FMSSTOP", "      Signature stop address",		LPC_FMC->FMSSTOP);
	rdump("FMSW0", "        Signature word",				LPC_FMC->FMSW0);
#endif /* DUMP_FMC */
#if DUMP_IOCON
	rprintf("LPC_IOCON\r\n");
//LPC_SYSCTL->SYSAHBCLKCTRL |= (1 << SYSCTL_CLOCK_IOCON);
	rdump("PIO0[ 0]", "     PIO0_17",		LPC_IOCON->PIO0[ 0]);
	rdump("PIO0[ 1]", "     PIO0_13",		LPC_IOCON->PIO0[ 1]);
	rdump("PIO0[ 2]", "     PIO0_12",		LPC_IOCON->PIO0[ 2]);
	rdump("PIO0[ 3]", "     PIO0_5",		LPC_IOCON->PIO0[ 3]);
	rdump("PIO0[ 4]", "     PIO0_4",		LPC_IOCON->PIO0[ 4]);
	rdump("PIO0[ 5]", "     PIO0_3",		LPC_IOCON->PIO0[ 5]);
	rdump("PIO0[ 6]", "     PIO0_2",		LPC_IOCON->PIO0[ 6]);
	rdump("PIO0[ 7]", "     PIO0_11",		LPC_IOCON->PIO0[ 7]);
	rdump("PIO0[ 8]", "     PIO0_10",		LPC_IOCON->PIO0[ 8]);
	rdump("PIO0[ 9]", "     PIO0_16",		LPC_IOCON->PIO0[ 9]);
	rdump("PIO0[10]", "     PIO0_15",		LPC_IOCON->PIO0[10]);
	rdump("PIO0[11]", "     PIO0_1",		LPC_IOCON->PIO0[11]);
	rdump("PIO0[12]", "     (rsrv)",		LPC_IOCON->PIO0[12]);
	rdump("PIO0[13]", "     PIO0_9",		LPC_IOCON->PIO0[13]);
	rdump("PIO0[14]", "     PIO0_8",		LPC_IOCON->PIO0[14]);
	rdump("PIO0[15]", "     PIO0_7",		LPC_IOCON->PIO0[15]);
	rdump("PIO0[16]", "     PIO0_6",		LPC_IOCON->PIO0[16]);
	rdump("PIO0[17]", "     PIO0_0",		LPC_IOCON->PIO0[17]);
	rdump("PIO0[18]", "     PIO0_14",		LPC_IOCON->PIO0[18]);
#endif /* DUMP_IOCON */
#if DUMP_SWM
	rprintf("LPC_SWM\r\n");
	rdump("PINASSIGN[0]", " Assign: U0_TXD, U0_RXD, U0_RTS, U0_CTS",			LPC_SWM->PINASSIGN[0]);
	rdump("PINASSIGN[1]", " Assign: U0_SCLK, U1_TXD, U1_RXD, U1_RTS",			LPC_SWM->PINASSIGN[1]);
	rdump("PINASSIGN[2]", " Assign: U1_CTS, U1_SCLK, U2_TXD, U2_RXD",			LPC_SWM->PINASSIGN[2]);
	rdump("PINASSIGN[3]", " Assign: U2_RTS, U2_CTS, U2_SCLK, SPI0_SCK",			LPC_SWM->PINASSIGN[3]);
	rdump("PINASSIGN[4]", " Assign: SPI0_MOSI, SPI0_MISO, SPI0_SSEL, SPI1_SCK",	LPC_SWM->PINASSIGN[4]);
	rdump("PINASSIGN[5]", " Assign: SPI1_MOSI, SPI1_MISO, SPI1_SSEL, CTIN_0",	LPC_SWM->PINASSIGN[5]);
	rdump("PINASSIGN[6]", " Assign: CTIN_1, CTIN_2, CTIN_3, CTOUT_0",			LPC_SWM->PINASSIGN[6]);
	rdump("PINASSIGN[7]", " Assign: CTOUT_1, CTOUT_2, CTOUT_3, I2C_SDA",		LPC_SWM->PINASSIGN[7]);
	rdump("PINASSIGN[8]", " Assign: I2C_SCL, ACMP_O, CLKOUT, GPIO_INT_BMAT",	LPC_SWM->PINASSIGN[8]);
	rdump("PINENABLE0", "   Enable: ACMP_I1, ACMP_I2, SWCLK, SWDIO, XTALIN, XTALOUT, RESET, CLKIN, VDDCMP",	LPC_SWM->PINENABLE0);
#endif /* DUMP_SWM */
#if DUMP_GPIO
	rprintf("LPC_GPIO_PORT\r\n");
	rdump("DIR[0]", "       Direction",		LPC_GPIO_PORT->DIR[0]);
	rdump("MASK[0]", "      Mask",			LPC_GPIO_PORT->MASK[0]);
	rdump("PIN[0]", "       Portpin",		LPC_GPIO_PORT->PIN[0]);
	rdump("MPIN[0]", "      Masked port",	LPC_GPIO_PORT->MPIN[0]);
	rdump("SET[0]", "       output bits",	LPC_GPIO_PORT->SET[0]);
		/* CLR[0]      (WO) Clear port */
		/* NOT[0]      (WO) Toggle port */
#endif /* DUMP_GPIO */
#if DUMP_UART0
	rprintf("LPC_USART0\r\n");
	rdump("CFG", "          Configuration",					LPC_USART0->CFG);
	rdump("CTRL", "         Control",						LPC_USART0->CTRL);
	rdump("STAT", "         Status",						LPC_USART0->STAT);
	rdump("INTENSET", "     Interrupt Enable read and set",	LPC_USART0->INTENSET);
		/* INTENCLR    (WO) Interrupt Enable clear */
///	rdump("RXDATA", "       Receive Data",					LPC_USART0->RXDATA);
///	rdump("RXDATA_STAT", "  Receive Data with status",		LPC_USART0->RXDATA_STAT);
///	rdump("TXDATA", "       Transmit data",					LPC_USART0->TXDATA);
	rdump("BRG", "          Baud Rate Generator",			LPC_USART0->BRG);
	rdump("INTSTAT", "      Interrupt status",				LPC_USART0->INTSTAT);
#endif /* DUMP_UART0 */
#if DUMP_UART1
	rprintf("LPC_USART1\r\n");
	rdump("CFG", "          Configuration",					LPC_USART1->CFG);
	rdump("CTRL", "         Control",						LPC_USART1->CTRL);
	rdump("STAT", "         Status",						LPC_USART1->STAT);
	rdump("INTENSET", "     Interrupt Enable read and set",	LPC_USART1->INTENSET);
		/* INTENCLR    (WO) Interrupt Enable clear */
///	rdump("RXDATA", "       Receive Data",					LPC_USART1->RXDATA);
///	rdump("RXDATA_STAT", "  Receive Data with status",		LPC_USART1->RXDATA_STAT);
///	rdump("TXDATA", "       Transmit data",					LPC_USART1->TXDATA);
	rdump("BRG", "          Baud Rate Generator",			LPC_USART1->BRG);
	rdump("INTSTAT", "      Interrupt status",				LPC_USART1->INTSTAT);
#endif /* DUMP_UART1 */
}

#if 0000000000
/*
 * confirm reset values of registers
 */
 +---------------------
 |/*
 | * hello... [0.03]
 | */
 |
 |SCB
 | 410CC600 =CPUID         ... ARMv6-M
 | 00000000 =ICSR
 | 00000000 =VTOR
 | FA050000 =AIRCR         ... little-endian
 | 00000000 =SCR
 | 00000208 =CCR
 | 00000000 =SHP[0]
 | 00000000 =SHP[1]
 | 00000000 =SHCSR
 |NVIC
 | 00000000 =ISER[0]
 | 00000000 =ICER[0]
 | 00000000 =ISPR[0]
 | 00000000 =ICPR[0]
 | 00000000 =IP[0]
 | 00000000 =IP[1]
 | 00000000 =IP[2]
 | 00000000 =IP[3]
 | 00000000 =IP[4]
 | 00000000 =IP[5]
 | 00000000 =IP[6]
 | 00000000 =IP[7]
 |SysTick
 | 00000000 =CTRL
 | 00FFFFFF =LOAD          ... 0x000000 ??
 | 00FFFFFF =VAL           ... 0x000000 ??
 | 00000000 =CALIB         ... 0x00000004 ??
 |LPC_SYSCTL
 | 00000002 =SYSMEMREMAP
 | 00001FFF =PRESETCTRL
 | 00000000 =SYSPLLCTRL
 | 00000000 =SYSPLLSTAT
 | 00000000 =SYSOSCCTRL
 | 00000000 =WDTOSCCTRL      ... 0xa0 ??
 | 00000003 =SYSRSTSTAT
 | 00000000 =SYSPLLCLKSEL
 | 00000000 =SYSPLLCLKUEN
 | 00000000 =MAINCLKSEL
 | 00000000 =MAINCLKUEN
 | 00000001 =SYSAHBCLKDIV
 | 000040DF =SYSAHBCLKCTRL   <<< enable uart0 by me
 | 00000001 =UARTCLKDIV      <<< set by me
 | 00000000 =CLKOUTSEL
 | 00000000 =CLKOUTUEN
 | 00000000 =CLKOUTDIV
 | 000000FF =UARTFRGDIV      <<< set by me
 | 000000A0 =UARTFRGMULT     <<< set by me
 | 00000000 =EXTTRACECMD
 | 0003F3FF =PIOPORCAP0      ... pulled up except true I2C pins
 | 00000000 =IOCONCLKDIV[0]
 | 00000000 =IOCONCLKDIV[1]
 | 00000000 =IOCONCLKDIV[2]
 | 00000000 =IOCONCLKDIV[3]
 | 00000000 =IOCONCLKDIV[4]
 | 00000000 =IOCONCLKDIV[5]
 | 00000000 =IOCONCLKDIV[6]
 | 00000000 =BODCTRL
 | 00000000 =SYSTCKCAL
 | 00000010 =IRQLATENCY
 | 00000000 =NMISRC
 | 00000000 =PINTSEL[0]
 | 00000000 =PINTSEL[1]
 | 00000000 =PINTSEL[2]
 | 00000000 =PINTSEL[3]
 | 00000000 =PINTSEL[4]
 | 00000000 =PINTSEL[5]
 | 00000000 =PINTSEL[6]
 | 00000000 =PINTSEL[7]
 | 00000000 =STARTERP0
 | 00000000 =STARTERP1
 | 0000FFFF =PDSLEEPCFG
 | 0000EDF0 =PDAWAKECFG
 | 0000EDF0 =PDRUNCFG
 | 00008100 =DEVICEID        ... LPC810
 |LPC_FMC
 | 0000C001 =FLASHCFG      ... 2clock/access
 | 00000000 =FMSSTART
 | 00000000 =FMSSTOP
 | 00000000 =FMSW0
 |LPC_IOCON
 | 00000000 =PIO0[ 0]      ... clock is disabled (some buffer data can be read)
 | 00000000 =PIO0[ 1]
 | 00000000 =PIO0[ 2]
 | 00000000 =PIO0[ 3]
 | 00000000 =PIO0[ 4]
 | 00000000 =PIO0[ 5]
 | 00000000 =PIO0[ 6]
 | 00000000 =PIO0[ 7]
 | 00000000 =PIO0[ 8]
 | 00000000 =PIO0[ 9]
 | 00000000 =PIO0[10]
 | 00000000 =PIO0[11]
 | 00000000 =PIO0[12]
 | 00000000 =PIO0[13]
 | 00000000 =PIO0[14]
 | 00000000 =PIO0[15]
 | 00000000 =PIO0[16]
 | 00000000 =PIO0[17]
 | 00000000 =PIO0[18]
   |LPC_IOCON                ... when clock given
   | 00000090 =PIO0[ 0]
   | 00000090 =PIO0[ 1]
   | 00000090 =PIO0[ 2]
   | 00000090 =PIO0[ 3]
   | 00000090 =PIO0[ 4]
   | 00000090 =PIO0[ 5]
   | 00000090 =PIO0[ 6]
   | 00000080 =PIO0[ 7]      ... true open-drain pin
   | 00000080 =PIO0[ 8]      ... true open-drain pin
   | 00000090 =PIO0[ 9]
   | 00000090 =PIO0[10]
   | 00000090 =PIO0[11]
   | 00000088 =PIO0[12]      ... (reserved)
   | 00000090 =PIO0[13]
   | 00000090 =PIO0[14]
   | 00000090 =PIO0[15]
   | 00000090 =PIO0[16]
   | 00000090 =PIO0[17]
   | 00000090 =PIO0[18]
 |LPC_SWM
 | FFFF0004 =PINASSIGN[0]    <<< set by me
 | FFFFFFFF =PINASSIGN[1]
 | FFFFFFFF =PINASSIGN[2]
 | FFFFFFFF =PINASSIGN[3]
 | FFFFFFFF =PINASSIGN[4]
 | FFFFFFFF =PINASSIGN[5]
 | FFFFFFFF =PINASSIGN[6]
 | FFFFFFFF =PINASSIGN[7]
 | FFFFFFFF =PINASSIGN[8]
 | 000001B3 =PINENABLE0
 |LPC_GPIO_PORT
 | 00000000 =DIR[0]
 | 00000000 =MASK[0]
 | 0003F3FF =PIN[0]
 | 0003F3FF =MPIN[0]
 | 00000000 =SET[0]
 |LPC_USART0
 | 00000005 =CFG           <<< set by me
 | 00000000 =CTRL
 | 00000002 =STAT
 | 00000000 =INTENSET
 | 00000007 =BRG
 | 00000000 =INTSTAT
 |LPC_USART1
 | 00000000 =CFG           ... clock is disabled as default
 | 00000000 =CTRL
 | 00000000 =STAT
 | 00000000 =INTENSET
 | 00000000 =BRG
 | 00000000 =INTSTAT
   |LPC_USART1             ... when clock given
   | 00000000 =CFG
   | 00000000 =CTRL
   | 0000000E =STAT
   | 00000000 =INTENSET
   | 00000000 =BRG
   | 00000000 =INTSTAT
 +---------------------

#endif /* 0000000000 */
